===========
 Changelog
===========

2.2 (2016-03-05)
================

- Update to ``bootstrap.py`` from `zc.buildout 2.3.1`.

- Update tests to only run with `py.test`.

- Update code and tests to changes in `icemac.addressbook 2.6`.


2.1.0 (2014-07-01)
==================

- The master data tab in the main menu is now highlighted when the importer
  is displayed.

- Update code and tests to changes in `icemac.addressbook 2.5`.

- Add `py.test` to run the tests.


2.0.0 (2013-11-03)
==================

- Updated supported Python version to 2.7.x.

- Adapted test setup and tests to `icemac.addressbook` version 2.0.


Previous versions
=================

See ``OLD_CHANGES.rst`` inside the package.
